@@ -1,6 +1,11 @@
 from django.db.models.query import QuerySet, EmptyQuerySet
 
 class DynamicChoicesQueryset(QuerySet):
+    
+    def _clone(self, klass=None, setup=False, **kwargs):
+        clone = super(DynamicChoicesQueryset, self)._clone(klass=None, setup=False, **kwargs)
+        clone._field = self._field
+        return clone
         
     def filter_for_instance(self, instance, data):
         return self._field._invoke_choices_callback(instance, self, data)
